# ramCOH

Library for processing and peak fitting of Raman spectra, targeted at CO<sub>2</sub> fluids and (hydrous) silicate glasses

## Documentation
Code documentation is available at [ramcoh.readthedocs.io](https://ramcoh.readthedocs.io/en/latest)

## Installation


